@@ -25,7 +25,7 @@ class WindowListPrefsWidget extends Gtk.Grid {
         let groupingLabel = '<b>%s</b>'.format(_('Window Grouping'));
         this.add(new Gtk.Label({
             label: groupingLabel, use_markup: true,
-            halign: Gtk.Align.START
+            halign: Gtk.Align.START,
         }));
 
         let align = new Gtk.Alignment({ left_padding: 12 });
@@ -34,7 +34,7 @@ class WindowListPrefsWidget extends Gtk.Grid {
         let grid = new Gtk.Grid({
             orientation: Gtk.Orientation.VERTICAL,
             row_spacing: 6,
-            column_spacing: 6
+            column_spacing: 6,
         });
         align.add(grid);
 
@@ -46,10 +46,11 @@ class WindowListPrefsWidget extends Gtk.Grid {
         let modeLabels = {
             'never': _('Never group windows'),
             'auto': _('Group windows when space is limited'),
-            'always': _('Always group windows')
+            'always': _('Always group windows'),
         };
 
         let radio = null;
+        let currentRadio = null;
         for (let i = 0; i < modes.length; i++) {
             let mode = modes[i];
             let label = modeLabels[mode];
@@ -59,28 +60,34 @@ class WindowListPrefsWidget extends Gtk.Grid {
             }
 
             radio = new Gtk.RadioButton({
-                active: currentMode == mode,
-                label: label,
-                group: radio
+                active: !i,
+                label,
+                group: radio,
             });
             grid.add(radio);
 
+            if (currentMode === mode)
+                currentRadio = radio;
+
             radio.connect('toggled', button => {
                 if (button.active)
                     this._settings.set_string('grouping-mode', mode);
             });
         }
 
+        if (currentRadio)
+            currentRadio.active = true;
+
         let check = new Gtk.CheckButton({
             label: _('Show on all monitors'),
-            margin_top: 6
+            margin_top: 6,
         });
         this._settings.bind('show-on-all-monitors', check, 'active', Gio.SettingsBindFlags.DEFAULT);
         this.add(check);
 
         check = new Gtk.CheckButton({
             label: _('Show windows from all workspaces'),
-            margin_top: 6
+            margin_top: 6,
         });
         this._settings.bind('display-all-workspaces', check, 'active', Gio.SettingsBindFlags.DEFAULT);
         this.add(check);
